@@ -6,7 +6,8 @@
 #'
 #' @param data a dataframe containing an outcome variable to be permuted (usually coming from nested bootstrap data)
 #' @param outcome the outcome as a string (i.e. "y")
-#'
+#' @param type model type, either "linear" or "logistic"
+#' @keywords internal
 #' @import bigstep
 #' @import dplyr
 #' @importFrom tibble rownames_to_column
@@ -14,9 +15,10 @@
 #' @importFrom utils globalVariables
 #' @importFrom stringr str_remove_all
 #'
+
 utils::globalVariables(c(".", "variable", "Estimate"))
 
-model_mbic <- function(data, outcome) {
+model_mbic <- function(data, outcome, type) {
   data <- data %>%
     as.data.frame()
   # TODO all_of might not work with doparralel, perhaps change to !!outcome ? see tidymodels parralel explanation.
@@ -27,7 +29,7 @@ model_mbic <- function(data, outcome) {
   x_temp <- data %>%
     select(-all_of(outcome))
 
-  bigstep_prepped <- bigstep::prepare_data(y_temp, x_temp, verbose = FALSE)
+  bigstep_prepped <- bigstep::prepare_data(y_temp, x_temp, verbose = FALSE, type = type)
 
   bigstep_prepped %>%
     reduce_matrix(minpv = 0.01) %>%
